# -- coding: utf-8 --
# Created by LoginRadius Development Team
# Copyright 2019 LoginRadius Inc. All rights reserved.
#


class SottApi:

    def __init__(self, lr_object):
        """
        :param lr_object: this is the reference to the parent LoginRadius object.
        """
        self._lr_object = lr_object

    def generate_sott(self, time_difference=None):
        """This API allows you to generate SOTT with a given expiration time.
        
        Args:
            time_difference: The time difference you would like to pass, If you not pass difference then the default value is 10 minutes
		
        Returns:
            Sott data For Registration
        18.28
        """

        query_parameters = {}
        query_parameters["apiKey"] = self._lr_object.get_api_key()
        query_parameters["apiSecret"] = self._lr_object.get_api_secret()
        if(time_difference is not None):
            query_parameters["timeDifference"] = time_difference

        resource_path = "identity/v2/manage/account/sott"
        return self._lr_object.execute("GET", resource_path, query_parameters, None)



#!/usr/bin/python
#################################################
# Class for Initilizing the LoginRadius Class   #
#################################################
# This is the main class to communicate with    #
# LoginRadius' Unified User Registration API.
#                                               #
# Please note that some API calls are for       #
# premium or enterprise members only.           #
# In which case, an exception will be raised.   #
#################################################
# Copyright 2019 LoginRadius Inc.               #
# - www.LoginRadius.com                         #
#################################################
# This file is part of the LoginRadius SDK      #
# package.                                      #
#################################################

__author__ = "LoginRadius"
__copyright__ = "Copyright 2019, LoginRadius"
__email__ = "developers@loginradius.com"
__status__ = "Production"
__version__ = "10.0.0.post1"

import json
import sys
import urllib3
import hmac
import hashlib
import base64
from collections import namedtuple
from datetime import datetime, timedelta
from importlib import import_module

import binascii
from cryptography.hazmat.backends import default_backend
from cryptography.hazmat.primitives.ciphers import Cipher
from cryptography.hazmat.primitives.ciphers import algorithms
from cryptography.hazmat.primitives.ciphers import modes
from pbkdf2 import PBKDF2

# Authentication APIs
from LoginRadius.api.authentication.authentication_api import AuthenticationApi
from LoginRadius.api.authentication.onetouchlogin_api import OneTouchLoginApi
from LoginRadius.api.authentication.passwordlesslogin_api import PasswordLessLoginApi
from LoginRadius.api.authentication.phoneauthentication_api import PhoneAuthenticationApi
from LoginRadius.api.authentication.riskbasedauthentication_api import RiskBasedAuthenticationApi
from LoginRadius.api.authentication.smartlogin_api import SmartLoginApi
from LoginRadius.api.authentication.pinauthentication_api import PINAuthenticationApi
# Account APIs
from LoginRadius.api.account.account_api import AccountApi
from LoginRadius.api.account.role_api import RoleApi
from LoginRadius.api.account.sott_api import SottApi
# Advance APIs
from LoginRadius.api.advanced.customobject_api import CustomObjectApi
from LoginRadius.api.advanced.customregistrationdata_api import CustomRegistrationDataApi
from LoginRadius.api.advanced.multifactorauthentication_api import MultiFactorAuthenticationApi
from LoginRadius.api.advanced.configuration_api import ConfigurationApi
from LoginRadius.api.advanced.webhook_api import WebHookApi
from LoginRadius.api.advanced.reauthentication_api import ReAuthenticationApi
from LoginRadius.api.advanced.consentmanagement_api import ConsentManagementApi

# Social APIs
from LoginRadius.api.social.nativesocial_api import NativeSocialApi
from LoginRadius.api.social.social_api import SocialApi
# exception
from LoginRadius.exceptions import Exceptions

class LoginRadius:
    """
    LoginRadius Class. Use this to obtain social data and other information
    from the LoginRadius API. Requires Python 2.7 or greater.
    """

    API_KEY = None
    API_SECRET = None
    LIBRARY = None
    CUSTOM_DOMAIN = None
    API_REQUEST_SIGNING = False
    SERVER_REGION = None
    CONST_INITVECTOR = "tu89geji340t89u2"
    CONST_KEYSIZE = 256

    def __init__(self):
        """
        Constructed when you want to retrieve social data with respect to the acquired token.
        :raise Exceptions.NoAPIKey: Raised if you did not set an API_KEY.
        :raise Exceptions.NoAPISecret: Raised if you did not set an API_SECRET.
        """
		
        self.error = {}
        self.sociallogin_raw = False
        self.bs = 16
        
        if not self.API_KEY:
            raise Exceptions.NoAPIKey

        if not self.API_SECRET:
            raise Exceptions.NoAPISecret

        if self.CUSTOM_DOMAIN is not None:
            self.SECURE_API_URL = self.CUSTOM_DOMAIN
        else:
            self.SECURE_API_URL = "https://api.loginradius.com/"

        self.CONFIG_API_URL = "https://config.lrcontent.com/"

        # proxy server detail
        self.IS_PROXY_ENABLE = False
        self.USER_NAME = "your-username"
        self.PASSWORD = "your-password"
        self.HOST = "host-name"
        self.PORT = "port"

        # Namedtuple for settings for each request and the api functions.
        self.settings = namedtuple(
            "Settings", ['library', 'urllib', 'urllib2', 'json', 'requests'])

        # We prefer to use requests with the updated urllib3 module.
        try:
            from distutils.version import StrictVersion
            import requests

            if StrictVersion(requests.__version__) < StrictVersion("2.0"):
                raise Exceptions.RequestsLibraryDated(requests.__version__)
            else:
                self._settings("requests")

        # However, we can use urllib if there is no requests or it is outdated.
        except (ImportError, Exceptions.RequestsLibraryDated):
            self._settings("urllib2")

        self.authentication = AuthenticationApi(self)
        self.one_touch_login = OneTouchLoginApi(self)
        self.password_less_login = PasswordLessLoginApi(self)
        self.risk_based_authentication = RiskBasedAuthenticationApi(self)
        self.smart_login = SmartLoginApi(self)
        self.phone_authentication = PhoneAuthenticationApi(self)
        self.pin_authentication = PINAuthenticationApi(self)
        self.consent_management = ConsentManagementApi(self)
        
        self.account = AccountApi(self)
        self.role = RoleApi(self)
        self.sott = SottApi(self)		
		
        self.custom_object = CustomObjectApi(self)
        self.custom_registration_data = CustomRegistrationDataApi(self)
        self.mfa = MultiFactorAuthenticationApi(self)
        self.configuration = ConfigurationApi(self)
        self.web_hook = WebHookApi(self)
        self.re_authentication = ReAuthenticationApi(self)
		
        self.native_social = NativeSocialApi(self)
        self.social = SocialApi(self)
        if sys.version_info[0] < 3:
            from urllib import quote
            self.quote = quote
        else:
            from urllib.parse import quote
            self.quote = quote

    #
    # Internal private functions
    #
    def _settings(self, library):
        """This sets the name tuple settings to whatever library you want.
        You may change this as you wish."""
        if LoginRadius.LIBRARY is not None:
            if LoginRadius.LIBRARY == "requests":
                self._set_requests()
            elif LoginRadius.LIBRARY == "urllib2":
                self._set_urllib2()
            else:
                raise Exceptions.InvalidLibrary(LoginRadius.LIBRARY)
        else:
            if library == "requests":
                self._set_requests()
            elif library == "urllib2":
                self._set_urllib2()
            else:
                raise Exceptions.InvalidLibrary(library)

    def _set_requests(self):
        """Change to the requests library to use."""
        self.settings.library = "requests"
        self.settings.requests = import_module("requests")
        self.settings.urllib2 = False

    def _set_urllib2(self):
        """Change to the requests urllib2 library to use."""
        if sys.version_info[0] == 2:
            self.settings.urllib2 = import_module("urllib2")
            self.settings.urllib = import_module("urllib")
        else:
            self.settings.urllib2 = import_module("urllib.request")
            self.settings.urllib = import_module("urllib.parse")
        self.settings.library = "urllib2"
        self.settings.requests = False
        self.settings.json = import_module("json")

    def get_expiry_time(self):
        utc_time = datetime.utcnow()
        expiry_time = utc_time + timedelta(hours=1)
        return expiry_time.strftime("%Y-%m-%d %H:%M:%S")

    def get_digest(self, expiry_time, url, payload=None):
        encoded_url = self.quote(url.lower(), safe='')
        signing_str = expiry_time + ":" + encoded_url
        signing_str = signing_str.lower()
        if payload is not None:
            signing_str = signing_str + ":" + json.dumps(payload)

        key_bytes = self.get_api_secret()
        data_bytes = signing_str
        if sys.version_info[0] >= 3:
            key_bytes = bytes(self.get_api_secret(), 'latin-1')
            data_bytes = bytes(signing_str, 'latin-1')
        dig = hmac.new(key_bytes, msg=data_bytes, digestmod=hashlib.sha256).digest()
        if sys.version_info[0] >= 3:
            return base64.b64encode(dig).decode("utf-8")
        return base64.b64encode(dig)

    def execute(self, method, resource_url, query_params, payload):
        api_end_point = self.SECURE_API_URL + resource_url

        if resource_url == "ciam/appinfo":
            api_end_point = self.CONFIG_API_URL + resource_url
        
        if self.SERVER_REGION is not None and self.SERVER_REGION != "":
            query_params['region'] = self.SERVER_REGION

        apiSecret = None
        if "apiSecret" in query_params:
            apiSecret = query_params['apiSecret']
            query_params.pop("apiSecret")

        headers = {'Content-Type': "application/json",
                   'Accept-encoding': 'gzip'}

        if "access_token" in query_params and "/auth" in resource_url:
            headers.update({"Authorization": "Bearer " + query_params['access_token']})
            query_params.pop("access_token")

        if "sott" in query_params:
            headers.update({"X-LoginRadius-Sott": query_params['sott']})
            query_params.pop("sott")

        if apiSecret and "/manage" in resource_url and not self.API_REQUEST_SIGNING:
            headers.update({"X-LoginRadius-ApiSecret": apiSecret})

        api_end_point = api_end_point + "?"
        for key, value in query_params.items():
            api_end_point = api_end_point + key + "=" + str(value) + "&"

        api_end_point = api_end_point[:-1]

        if apiSecret and "/manage" in resource_url and self.API_REQUEST_SIGNING:
            expiry_time = self.get_expiry_time()
            digest = self.get_digest(expiry_time, api_end_point, payload)
            headers.update({"X-Request-Expires": expiry_time})
            headers.update({"digest": "SHA-256=" + digest})

        try:
            if method.upper() == 'GET':
                return self._get_json(api_end_point, {}, headers)
            else:
                return self.__submit_json(method.upper(), api_end_point, payload, headers)
        except IOError as e:
            return {
                'ErrorCode': 105,
                'Description': e.message
            }
        except ValueError as e:
            return {
                'ErrorCode': 102,
                'Description': e.message
            }
        except Exception as e:
            return {
                'ErrorCode': 101,
                'Description': e.message
            }

    def _get_json(self, url, payload, HEADERS):
        """Get JSON from LoginRadius"""

        proxies = self._get_proxy()

        if self.settings.requests:
            r = self.settings.requests.get(
                url, proxies=proxies, params=payload, headers=HEADERS)
            return self._process_result(r.json())
        else:
            http = urllib3.PoolManager()
            urllib3.disable_warnings(urllib3.exceptions.InsecureRequestWarning)
            r = http.request('GET', url, fields=payload, headers=HEADERS)
            return json.loads(r.data.decode('utf-8'))

    def __submit_json(self, method, url, payload, HEADERS):
        if self.settings.requests:
            import json
            proxies = self._get_proxy()
            if method == 'PUT':
                r = self.settings.requests.put(
                    url, proxies=proxies, data=json.dumps(payload), headers=HEADERS)
            elif method == 'DELETE':
                r = self.settings.requests.delete(
                    url, proxies=proxies, data=json.dumps(payload), headers=HEADERS)
            else:
                r = self.settings.requests.post(
                    url, proxies=proxies, data=json.dumps(payload), headers=HEADERS)
            return self._process_result(r.json())

        else:
            import json
            data = json.dumps(payload)
            if sys.version_info[0] == 3:
                data = data.encode('utf-8')

            r = self.settings.urllib2.Request(
                url, data, {'Content-Type': 'application/json', 'Accept-encoding': 'gzip'})
            if method == 'PUT' or method == 'DELETE':
                r.get_method = lambda: method
            for key, value in HEADERS.items():
                r.add_header(key, value)
            try:
                result = self.settings.urllib2.urlopen(r)
            except self.settings.urllib2.HTTPError as e:
                return json.loads(e.read())

            import codecs
            reader = codecs.getreader("utf-8")
            return self._process_result(self.settings.json.load(reader(result)))

    def get_api_key(self):
        return self.API_KEY

    def get_api_secret(self):
        return self.API_SECRET

    def _get_proxy(self):
        if self.IS_PROXY_ENABLE:
            proxies = {'https': 'https://' + self.USER_NAME + ':' + self.PASSWORD + '@' + self.HOST + ':' + self.PORT}
        else:
            proxies = {}
        return proxies

    def _process_result(self, result):
        # For now, directly returning the API response
        return result

    #
    # Public functions
    #
    def change_library(self, library):
        self._settings(library)

    def is_null_or_whitespace(self, value):
        if value is None:
            return True
        if str(value).strip() == "":
            return True

    def get_validation_message(self, field):
        return "Invalid value for field " + str(field)
    
    def get_sott(self, time='10', getLRserverTime=False):
        if getLRserverTime:
            result = self.configuration.get_server_info()
            print(result)
            if result.get('Sott') is not None:
                Sott = result.get('Sott')
                for timeKey, val in Sott.items():
                    if timeKey == 'StartTime':
                        now = val
                    if timeKey == 'EndTime':
                        now_plus_10m = val
            else:
                now = datetime.utcnow()
                now = now - timedelta(minutes=5)
                now_plus_10m = now + timedelta(minutes=10)
                now = now.strftime("%Y/%m/%d %I:%M:%S")
                now_plus_10m = now_plus_10m.strftime("%Y/%m/%d %I:%M:%S")

        else:
            now = datetime.utcnow()
            now = now - timedelta(minutes=5)
            now_plus_10m = now + timedelta(minutes=10)
            now = now.strftime("%Y/%m/%d %I:%M:%S")
            now_plus_10m = now_plus_10m.strftime("%Y/%m/%d %I:%M:%S")

        plaintext = now + "#" + self.API_KEY + "#" + now_plus_10m
        padding = 16 - (len(plaintext) % 16)
        if sys.version_info[0] == 3:
            plaintext += (bytes([padding]) * padding).decode()
        else:
            plaintext += (chr(padding) * padding).decode()

        salt = "\0\0\0\0\0\0\0\0"
        cipher_key = PBKDF2(self.API_SECRET,
                            salt, 10000).read(self.CONST_KEYSIZE // 8)

        if sys.version_info[0] == 3:
            iv = bytes(self.CONST_INITVECTOR, 'utf-8')
            text = bytes(plaintext, 'utf-8')
        else:
            iv = str(self.CONST_INITVECTOR)
            text = str(plaintext)

        backend = default_backend()
        cipher = Cipher(algorithms.AES(cipher_key),
                        modes.CBC(iv), backend=backend)
        encryptor = cipher.encryptor()
        ct = encryptor.update(text) + encryptor.finalize()

        base64cipher = base64.b64encode(ct)

        md5 = hashlib.md5()
        md5.update(base64cipher.decode('utf8').encode('ascii'))
        return base64cipher.decode('utf-8')+"*"+binascii.hexlify(md5.digest()).decode('ascii')



# -- coding: utf-8 --
# Created by LoginRadius Development Team
# Copyright 2019 LoginRadius Inc. All rights reserved.
#


class ConsentManagementApi:

    def __init__(self, lr_object):
        """
        :param lr_object: this is the reference to the parent LoginRadius object.
        """
        self._lr_object = lr_object

    def get_consent_logs_by_uid(self, uid):
        """This API is used to get the Consent logs of the user.
        
        Args:
            uid: UID, the unified identifier for each user account
		
        Returns:
            Response containing consent logs
        18.37
        """

        if(self._lr_object.is_null_or_whitespace(uid)):
            raise Exception(self._lr_object.get_validation_message("uid"))

        query_parameters = {}
        query_parameters["apiKey"] = self._lr_object.get_api_key()
        query_parameters["apiSecret"] = self._lr_object.get_api_secret()

        resource_path = "identity/v2/manage/account/" + uid + "/consent/logs"
        return self._lr_object.execute("GET", resource_path, query_parameters, None)

    def submit_consent_by_consent_token(self, consent_token, consent_submit_model):
        """This API is to submit consent form using consent token.
        
        Args:
            consent_token: The consent token received after login error 1226 
            consent_submit_model: Model class containing list of multiple consent
		
        Returns:
            Response containing User Profile Data and access token
        43.1
        """

        if(self._lr_object.is_null_or_whitespace(consent_token)):
            raise Exception(self._lr_object.get_validation_message("consent_token"))
        if(consent_submit_model is None):
            raise Exception(self._lr_object.get_validation_message("consent_submit_model"))

        query_parameters = {}
        query_parameters["apiKey"] = self._lr_object.get_api_key()
        query_parameters["consentToken"] = consent_token

        resource_path = "identity/v2/auth/consent"
        return self._lr_object.execute("POST", resource_path, query_parameters, consent_submit_model)

    def get_consent_logs(self, access_token):
        """This API is used to fetch consent logs.
        
        Args:
            access_token: Uniquely generated identifier key by LoginRadius that is activated after successful authentication.
		
        Returns:
            Response containing consent logs
        43.2
        """

        if(self._lr_object.is_null_or_whitespace(access_token)):
            raise Exception(self._lr_object.get_validation_message("access_token"))

        query_parameters = {}
        query_parameters["access_token"] = access_token
        query_parameters["apiKey"] = self._lr_object.get_api_key()

        resource_path = "identity/v2/auth/consent/logs"
        return self._lr_object.execute("GET", resource_path, query_parameters, None)

    def submit_consent_by_access_token(self, access_token, consent_submit_model):
        """API to provide a way to end user to submit a consent form for particular event type.
        
        Args:
            access_token: Uniquely generated identifier key by LoginRadius that is activated after successful authentication.
            consent_submit_model: Model class containing list of multiple consent
		
        Returns:
            Response containing Definition for Complete profile data
        43.3
        """

        if(self._lr_object.is_null_or_whitespace(access_token)):
            raise Exception(self._lr_object.get_validation_message("access_token"))
        if(consent_submit_model is None):
            raise Exception(self._lr_object.get_validation_message("consent_submit_model"))

        query_parameters = {}
        query_parameters["access_token"] = access_token
        query_parameters["apiKey"] = self._lr_object.get_api_key()

        resource_path = "identity/v2/auth/consent/profile"
        return self._lr_object.execute("POST", resource_path, query_parameters, consent_submit_model)

    def verify_consent_by_access_token(self, access_token, event, is_custom):
        """This API is used to check if consent is submitted for a particular event or not.
        
        Args:
            access_token: Uniquely generated identifier key by LoginRadius that is activated after successful authentication.
            event: Allowed events: Login, Register, UpdateProfile, ResetPassword, ChangePassword, emailVerification, AddEmail, RemoveEmail, BlockAccount, DeleteAccount, SetUsername, AssignRoles, UnassignRoles, SetPassword, LinkAccount, UnlinkAccount, UpdatePhoneId, VerifyPhoneNumber, CreateCustomObject, UpdateCustomobject, DeleteCustomObject
            is_custom: true/false
		
        Returns:
            Response containing consent profile
        43.4
        """

        if(self._lr_object.is_null_or_whitespace(access_token)):
            raise Exception(self._lr_object.get_validation_message("access_token"))

        if(self._lr_object.is_null_or_whitespace(event)):
            raise Exception(self._lr_object.get_validation_message("event"))

        query_parameters = {}
        query_parameters["access_token"] = access_token
        query_parameters["apiKey"] = self._lr_object.get_api_key()
        query_parameters["event"] = event
        query_parameters["isCustom"] = is_custom

        resource_path = "identity/v2/auth/consent/verify"
        return self._lr_object.execute("GET", resource_path, query_parameters, None)

    def update_consent_profile_by_access_token(self, access_token, consent_update_model):
        """This API is to update consents using access token.
        
        Args:
            access_token: Uniquely generated identifier key by LoginRadius that is activated after successful authentication.
            consent_update_model: Model class containg list of multiple consent
		
        Returns:
            Response containing consent profile
        43.5
        """

        if(self._lr_object.is_null_or_whitespace(access_token)):
            raise Exception(self._lr_object.get_validation_message("access_token"))
        if(consent_update_model is None):
            raise Exception(self._lr_object.get_validation_message("consent_update_model"))

        query_parameters = {}
        query_parameters["access_token"] = access_token
        query_parameters["apiKey"] = self._lr_object.get_api_key()

        resource_path = "identity/v2/auth/consent"
        return self._lr_object.execute("PUT", resource_path, query_parameters, consent_update_model)



# -- coding: utf-8 --
# Created by LoginRadius Development Team
# Copyright 2019 LoginRadius Inc. All rights reserved.
#


class CustomObjectApi:

    def __init__(self, lr_object):
        """
        :param lr_object: this is the reference to the parent LoginRadius object.
        """
        self._lr_object = lr_object

    def create_custom_object_by_token(self, access_token, object_name, payload):
        """This API is used to write information in JSON format to the custom object for the specified account.
        
        Args:
            access_token: Uniquely generated identifier key by LoginRadius that is activated after successful authentication.
            object_name: LoginRadius Custom Object Name
            payload: LoginRadius Custom Object Name
		
        Returns:
            Response containing Definition for Complete user custom object data
        6.1
        """

        if(self._lr_object.is_null_or_whitespace(access_token)):
            raise Exception(self._lr_object.get_validation_message("access_token"))

        if(self._lr_object.is_null_or_whitespace(object_name)):
            raise Exception(self._lr_object.get_validation_message("object_name"))
        if(payload is None):
            raise Exception(self._lr_object.get_validation_message("payload"))

        query_parameters = {}
        query_parameters["access_token"] = access_token
        query_parameters["apiKey"] = self._lr_object.get_api_key()
        query_parameters["objectName"] = object_name

        resource_path = "identity/v2/auth/customobject"
        return self._lr_object.execute("POST", resource_path, query_parameters, payload)

    def update_custom_object_by_token(self, access_token, object_name, object_record_id,
        payload, update_type=None):
        """This API is used to update the specified custom object data of the specified account. If the value of updatetype is 'replace' then it will fully replace custom object with the new custom object and if the value of updatetype is 'partialreplace' then it will perform an upsert type operation
        
        Args:
            access_token: Uniquely generated identifier key by LoginRadius that is activated after successful authentication.
            object_name: LoginRadius Custom Object Name
            object_record_id: Unique identifier of the user's record in Custom Object
            payload: LoginRadius Custom Object Name
            update_type: Possible values: replace, partialreplace.
		
        Returns:
            Response containing Definition for Complete user custom object data
        6.2
        """

        if(self._lr_object.is_null_or_whitespace(access_token)):
            raise Exception(self._lr_object.get_validation_message("access_token"))

        if(self._lr_object.is_null_or_whitespace(object_name)):
            raise Exception(self._lr_object.get_validation_message("object_name"))

        if(self._lr_object.is_null_or_whitespace(object_record_id)):
            raise Exception(self._lr_object.get_validation_message("object_record_id"))
        if(payload is None):
            raise Exception(self._lr_object.get_validation_message("payload"))

        query_parameters = {}
        query_parameters["access_token"] = access_token
        query_parameters["apiKey"] = self._lr_object.get_api_key()
        query_parameters["objectName"] = object_name
        if(update_type is not None):
            query_parameters["updateType"] = update_type

        resource_path = "identity/v2/auth/customobject/" + object_record_id
        return self._lr_object.execute("PUT", resource_path, query_parameters, payload)

    def get_custom_object_by_token(self, access_token, object_name):
        """This API is used to retrieve the specified Custom Object data for the specified account.
        
        Args:
            access_token: Uniquely generated identifier key by LoginRadius that is activated after successful authentication.
            object_name: LoginRadius Custom Object Name
		
        Returns:
            Complete user CustomObject data
        6.3
        """

        if(self._lr_object.is_null_or_whitespace(access_token)):
            raise Exception(self._lr_object.get_validation_message("access_token"))

        if(self._lr_object.is_null_or_whitespace(object_name)):
            raise Exception(self._lr_object.get_validation_message("object_name"))

        query_parameters = {}
        query_parameters["access_token"] = access_token
        query_parameters["apiKey"] = self._lr_object.get_api_key()
        query_parameters["objectName"] = object_name

        resource_path = "identity/v2/auth/customobject"
        return self._lr_object.execute("GET", resource_path, query_parameters, None)

    def get_custom_object_by_record_id_and_token(self, access_token, object_name, object_record_id):
        """This API is used to retrieve the Custom Object data for the specified account.
        
        Args:
            access_token: Uniquely generated identifier key by LoginRadius that is activated after successful authentication.
            object_name: LoginRadius Custom Object Name
            object_record_id: Unique identifier of the user's record in Custom Object
		
        Returns:
            Response containing Definition for Complete user custom object data
        6.4
        """

        if(self._lr_object.is_null_or_whitespace(access_token)):
            raise Exception(self._lr_object.get_validation_message("access_token"))

        if(self._lr_object.is_null_or_whitespace(object_name)):
            raise Exception(self._lr_object.get_validation_message("object_name"))

        if(self._lr_object.is_null_or_whitespace(object_record_id)):
            raise Exception(self._lr_object.get_validation_message("object_record_id"))

        query_parameters = {}
        query_parameters["access_token"] = access_token
        query_parameters["apiKey"] = self._lr_object.get_api_key()
        query_parameters["objectName"] = object_name

        resource_path = "identity/v2/auth/customobject/" + object_record_id
        return self._lr_object.execute("GET", resource_path, query_parameters, None)

    def delete_custom_object_by_token(self, access_token, object_name, object_record_id):
        """This API is used to remove the specified Custom Object data using ObjectRecordId of a specified account.
        
        Args:
            access_token: Uniquely generated identifier key by LoginRadius that is activated after successful authentication.
            object_name: LoginRadius Custom Object Name
            object_record_id: Unique identifier of the user's record in Custom Object
		
        Returns:
            Response containing Definition of Delete Request
        6.5
        """

        if(self._lr_object.is_null_or_whitespace(access_token)):
            raise Exception(self._lr_object.get_validation_message("access_token"))

        if(self._lr_object.is_null_or_whitespace(object_name)):
            raise Exception(self._lr_object.get_validation_message("object_name"))

        if(self._lr_object.is_null_or_whitespace(object_record_id)):
            raise Exception(self._lr_object.get_validation_message("object_record_id"))

        query_parameters = {}
        query_parameters["access_token"] = access_token
        query_parameters["apiKey"] = self._lr_object.get_api_key()
        query_parameters["objectName"] = object_name

        resource_path = "identity/v2/auth/customobject/" + object_record_id
        return self._lr_object.execute("DELETE", resource_path, query_parameters, None)

    def create_custom_object_by_uid(self, object_name, payload, uid):
        """This API is used to write information in JSON format to the custom object for the specified account.
        
        Args:
            object_name: LoginRadius Custom Object Name
            payload: LoginRadius Custom Object Name
            uid: UID, the unified identifier for each user account
		
        Returns:
            Response containing Definition for Complete user custom object data
        19.1
        """

        if(self._lr_object.is_null_or_whitespace(object_name)):
            raise Exception(self._lr_object.get_validation_message("object_name"))
        if(payload is None):
            raise Exception(self._lr_object.get_validation_message("payload"))

        if(self._lr_object.is_null_or_whitespace(uid)):
            raise Exception(self._lr_object.get_validation_message("uid"))

        query_parameters = {}
        query_parameters["apiKey"] = self._lr_object.get_api_key()
        query_parameters["apiSecret"] = self._lr_object.get_api_secret()
        query_parameters["objectName"] = object_name

        resource_path = "identity/v2/manage/account/" + uid + "/customobject"
        return self._lr_object.execute("POST", resource_path, query_parameters, payload)

    def update_custom_object_by_uid(self, object_name, object_record_id, payload,
        uid, update_type=None):
        """This API is used to update the specified custom object data of a specified account. If the value of updatetype is 'replace' then it will fully replace custom object with new custom object and if the value of updatetype is partialreplace then it will perform an upsert type operation.
        
        Args:
            object_name: LoginRadius Custom Object Name
            object_record_id: Unique identifier of the user's record in Custom Object
            payload: LoginRadius Custom Object Name
            uid: UID, the unified identifier for each user account
            update_type: Possible values: replace, partialreplace.
		
        Returns:
            Response containing Definition for Complete user custom object data
        19.2
        """

        if(self._lr_object.is_null_or_whitespace(object_name)):
            raise Exception(self._lr_object.get_validation_message("object_name"))

        if(self._lr_object.is_null_or_whitespace(object_record_id)):
            raise Exception(self._lr_object.get_validation_message("object_record_id"))
        if(payload is None):
            raise Exception(self._lr_object.get_validation_message("payload"))

        if(self._lr_object.is_null_or_whitespace(uid)):
            raise Exception(self._lr_object.get_validation_message("uid"))

        query_parameters = {}
        query_parameters["apiKey"] = self._lr_object.get_api_key()
        query_parameters["apiSecret"] = self._lr_object.get_api_secret()
        query_parameters["objectName"] = object_name
        if(update_type is not None):
            query_parameters["updateType"] = update_type

        resource_path = "identity/v2/manage/account/" + uid + "/customobject/" + object_record_id
        return self._lr_object.execute("PUT", resource_path, query_parameters, payload)

    def get_custom_object_by_uid(self, object_name, uid):
        """This API is used to retrieve all the custom objects by UID from cloud storage.
        
        Args:
            object_name: LoginRadius Custom Object Name
            uid: UID, the unified identifier for each user account
		
        Returns:
            Complete user CustomObject data
        19.3
        """

        if(self._lr_object.is_null_or_whitespace(object_name)):
            raise Exception(self._lr_object.get_validation_message("object_name"))

        if(self._lr_object.is_null_or_whitespace(uid)):
            raise Exception(self._lr_object.get_validation_message("uid"))

        query_parameters = {}
        query_parameters["apiKey"] = self._lr_object.get_api_key()
        query_parameters["apiSecret"] = self._lr_object.get_api_secret()
        query_parameters["objectName"] = object_name

        resource_path = "identity/v2/manage/account/" + uid + "/customobject"
        return self._lr_object.execute("GET", resource_path, query_parameters, None)

    def get_custom_object_by_record_id(self, object_name, object_record_id, uid):
        """This API is used to retrieve the Custom Object data for the specified account.
        
        Args:
            object_name: LoginRadius Custom Object Name
            object_record_id: Unique identifier of the user's record in Custom Object
            uid: UID, the unified identifier for each user account
		
        Returns:
            Response containing Definition for Complete user custom object data
        19.4
        """

        if(self._lr_object.is_null_or_whitespace(object_name)):
            raise Exception(self._lr_object.get_validation_message("object_name"))

        if(self._lr_object.is_null_or_whitespace(object_record_id)):
            raise Exception(self._lr_object.get_validation_message("object_record_id"))

        if(self._lr_object.is_null_or_whitespace(uid)):
            raise Exception(self._lr_object.get_validation_message("uid"))

        query_parameters = {}
        query_parameters["apiKey"] = self._lr_object.get_api_key()
        query_parameters["apiSecret"] = self._lr_object.get_api_secret()
        query_parameters["objectName"] = object_name

        resource_path = "identity/v2/manage/account/" + uid + "/customobject/" + object_record_id
        return self._lr_object.execute("GET", resource_path, query_parameters, None)

    def delete_custom_object_by_record_id(self, object_name, object_record_id, uid):
        """This API is used to remove the specified Custom Object data using ObjectRecordId of specified account.
        
        Args:
            object_name: LoginRadius Custom Object Name
            object_record_id: Unique identifier of the user's record in Custom Object
            uid: UID, the unified identifier for each user account
		
        Returns:
            Response containing Definition of Delete Request
        19.5
        """

        if(self._lr_object.is_null_or_whitespace(object_name)):
            raise Exception(self._lr_object.get_validation_message("object_name"))

        if(self._lr_object.is_null_or_whitespace(object_record_id)):
            raise Exception(self._lr_object.get_validation_message("object_record_id"))

        if(self._lr_object.is_null_or_whitespace(uid)):
            raise Exception(self._lr_object.get_validation_message("uid"))

        query_parameters = {}
        query_parameters["apiKey"] = self._lr_object.get_api_key()
        query_parameters["apiSecret"] = self._lr_object.get_api_secret()
        query_parameters["objectName"] = object_name

        resource_path = "identity/v2/manage/account/" + uid + "/customobject/" + object_record_id
        return self._lr_object.execute("DELETE", resource_path, query_parameters, None)



# -- coding: utf-8 --
# Created by LoginRadius Development Team
# Copyright 2019 LoginRadius Inc. All rights reserved.
#


class SocialApi:

    def __init__(self, lr_object):
        """
        :param lr_object: this is the reference to the parent LoginRadius object.
        """
        self._lr_object = lr_object

    def exchange_access_token(self, token):
        """This API Is used to translate the Request Token returned during authentication into an Access Token that can be used with other API calls.
        
        Args:
            token: Token generated from a successful oauth from social platform
		
        Returns:
            Response containing Definition of Complete Token data
        20.1
        """

        if(self._lr_object.is_null_or_whitespace(token)):
            raise Exception(self._lr_object.get_validation_message("token"))

        query_parameters = {}
        query_parameters["secret"] = self._lr_object.get_api_secret()
        query_parameters["token"] = token

        resource_path = "api/v2/access_token"
        return self._lr_object.execute("GET", resource_path, query_parameters, None)

    def refresh_access_token(self, access_token, expires_in=0):
        """The Refresh Access Token API is used to refresh the provider access token after authentication. It will be valid for up to 60 days on LoginRadius depending on the provider. In order to use the access token in other APIs, always refresh the token using this API.<br><br><b>Supported Providers :</b> Facebook,Yahoo,Google,Twitter, Linkedin.<br><br> Contact LoginRadius support team to enable this API.
        
        Args:
            access_token: Uniquely generated identifier key by LoginRadius that is activated after successful authentication.
            expires_in: Allows you to specify a desired expiration time in minutes for the newly issued access_token.
		
        Returns:
            Response containing Definition of Complete Token data
        20.2
        """

        if(self._lr_object.is_null_or_whitespace(access_token)):
            raise Exception(self._lr_object.get_validation_message("access_token"))

        query_parameters = {}
        query_parameters["access_token"] = access_token
        query_parameters["secret"] = self._lr_object.get_api_secret()
        if(expires_in is not None):
            query_parameters["expiresIn"] = expires_in

        resource_path = "api/v2/access_token/refresh"
        return self._lr_object.execute("GET", resource_path, query_parameters, None)

    def validate_access_token(self, access_token):
        """This API validates access token, if valid then returns a response with its expiry otherwise error.
        
        Args:
            access_token: Uniquely generated identifier key by LoginRadius that is activated after successful authentication.
		
        Returns:
            Response containing Definition of Complete Token data
        20.9
        """

        if(self._lr_object.is_null_or_whitespace(access_token)):
            raise Exception(self._lr_object.get_validation_message("access_token"))

        query_parameters = {}
        query_parameters["access_token"] = access_token
        query_parameters["key"] = self._lr_object.get_api_key()
        query_parameters["secret"] = self._lr_object.get_api_secret()

        resource_path = "api/v2/access_token/validate"
        return self._lr_object.execute("GET", resource_path, query_parameters, None)

    def in_validate_access_token(self, access_token):
        """This api invalidates the active access token or expires an access token validity.
        
        Args:
            access_token: Uniquely generated identifier key by LoginRadius that is activated after successful authentication.
		
        Returns:
            Response containing Definition for Complete Validation data
        20.10
        """

        if(self._lr_object.is_null_or_whitespace(access_token)):
            raise Exception(self._lr_object.get_validation_message("access_token"))

        query_parameters = {}
        query_parameters["access_token"] = access_token
        query_parameters["key"] = self._lr_object.get_api_key()
        query_parameters["secret"] = self._lr_object.get_api_secret()

        resource_path = "api/v2/access_token/invalidate"
        return self._lr_object.execute("GET", resource_path, query_parameters, None)

    def get_active_session(self, token):
        """This api is use to get all active session by Access Token.
        
        Args:
            token: Token generated from a successful oauth from social platform
		
        Returns:
            Response containing Definition for Complete active sessions
        20.11.1
        """

        if(self._lr_object.is_null_or_whitespace(token)):
            raise Exception(self._lr_object.get_validation_message("token"))

        query_parameters = {}
        query_parameters["key"] = self._lr_object.get_api_key()
        query_parameters["secret"] = self._lr_object.get_api_secret()
        query_parameters["token"] = token

        resource_path = "api/v2/access_token/activesession"
        return self._lr_object.execute("GET", resource_path, query_parameters, None)

    def get_active_session_by_account_id(self, account_id):
        """This api is used to get all active sessions by AccountID(UID).
        
        Args:
            account_id: UID, the unified identifier for each user account
		
        Returns:
            Response containing Definition for Complete active sessions
        20.11.2
        """

        if(self._lr_object.is_null_or_whitespace(account_id)):
            raise Exception(self._lr_object.get_validation_message("account_id"))

        query_parameters = {}
        query_parameters["accountId"] = account_id
        query_parameters["key"] = self._lr_object.get_api_key()
        query_parameters["secret"] = self._lr_object.get_api_secret()

        resource_path = "api/v2/access_token/activesession"
        return self._lr_object.execute("GET", resource_path, query_parameters, None)

    def get_active_session_by_profile_id(self, profile_id):
        """This api is used to get all active sessions by ProfileId.
        
        Args:
            profile_id: Social Provider Id
		
        Returns:
            Response containing Definition for Complete active sessions
        20.11.3
        """

        if(self._lr_object.is_null_or_whitespace(profile_id)):
            raise Exception(self._lr_object.get_validation_message("profile_id"))

        query_parameters = {}
        query_parameters["key"] = self._lr_object.get_api_key()
        query_parameters["profileId"] = profile_id
        query_parameters["secret"] = self._lr_object.get_api_secret()

        resource_path = "api/v2/access_token/activesession"
        return self._lr_object.execute("GET", resource_path, query_parameters, None)

    def get_albums(self, access_token):
        """<b>Supported Providers:</b> Facebook, Google, Live, Vkontakte.<br><br> This API returns the photo albums associated with the passed in access tokens Social Profile.
        
        Args:
            access_token: Uniquely generated identifier key by LoginRadius that is activated after successful authentication.
		
        Returns:
            Response Containing List of Album Data
        22.2.1
        """

        if(self._lr_object.is_null_or_whitespace(access_token)):
            raise Exception(self._lr_object.get_validation_message("access_token"))

        query_parameters = {}
        query_parameters["access_token"] = access_token

        resource_path = "api/v2/album"
        return self._lr_object.execute("GET", resource_path, query_parameters, None)

    def get_albums_with_cursor(self, access_token, next_cursor):
        """<b>Supported Providers:</b> Facebook, Google, Live, Vkontakte.<br><br> This API returns the photo albums associated with the passed in access tokens Social Profile.
        
        Args:
            access_token: Uniquely generated identifier key by LoginRadius that is activated after successful authentication.
            next_cursor: Cursor value if not all contacts can be retrieved once.
		
        Returns:
            Response Model containing Albums with next cursor
        22.2.2
        """

        if(self._lr_object.is_null_or_whitespace(access_token)):
            raise Exception(self._lr_object.get_validation_message("access_token"))

        if(self._lr_object.is_null_or_whitespace(next_cursor)):
            raise Exception(self._lr_object.get_validation_message("next_cursor"))

        query_parameters = {}
        query_parameters["access_token"] = access_token
        query_parameters["nextCursor"] = next_cursor

        resource_path = "api/v2/album"
        return self._lr_object.execute("GET", resource_path, query_parameters, None)

    def get_audios(self, access_token):
        """The Audio API is used to get audio files data from the user's social account.<br><br><b>Supported Providers:</b> Live, Vkontakte
        
        Args:
            access_token: Uniquely generated identifier key by LoginRadius that is activated after successful authentication.
		
        Returns:
            Response Containing List of Audio Data
        24.2.1
        """

        if(self._lr_object.is_null_or_whitespace(access_token)):
            raise Exception(self._lr_object.get_validation_message("access_token"))

        query_parameters = {}
        query_parameters["access_token"] = access_token

        resource_path = "api/v2/audio"
        return self._lr_object.execute("GET", resource_path, query_parameters, None)

    def get_audios_with_cursor(self, access_token, next_cursor):
        """The Audio API is used to get audio files data from the user's social account.<br><br><b>Supported Providers:</b> Live, Vkontakte
        
        Args:
            access_token: Uniquely generated identifier key by LoginRadius that is activated after successful authentication.
            next_cursor: Cursor value if not all contacts can be retrieved once.
		
        Returns:
            Response Model containing Audio with next cursor
        24.2.2
        """

        if(self._lr_object.is_null_or_whitespace(access_token)):
            raise Exception(self._lr_object.get_validation_message("access_token"))

        if(self._lr_object.is_null_or_whitespace(next_cursor)):
            raise Exception(self._lr_object.get_validation_message("next_cursor"))

        query_parameters = {}
        query_parameters["access_token"] = access_token
        query_parameters["nextCursor"] = next_cursor

        resource_path = "api/v2/audio"
        return self._lr_object.execute("GET", resource_path, query_parameters, None)

    def get_check_ins(self, access_token):
        """The Check In API is used to get check Ins data from the user's social account.<br><br><b>Supported Providers:</b> Facebook, Foursquare, Vkontakte
        
        Args:
            access_token: Uniquely generated identifier key by LoginRadius that is activated after successful authentication.
		
        Returns:
            Response Containing List of CheckIn Data
        25.2.1
        """

        if(self._lr_object.is_null_or_whitespace(access_token)):
            raise Exception(self._lr_object.get_validation_message("access_token"))

        query_parameters = {}
        query_parameters["access_token"] = access_token

        resource_path = "api/v2/checkin"
        return self._lr_object.execute("GET", resource_path, query_parameters, None)

    def get_check_ins_with_cursor(self, access_token, next_cursor):
        """The Check In API is used to get check Ins data from the user's social account.<br><br><b>Supported Providers:</b> Facebook, Foursquare, Vkontakte
        
        Args:
            access_token: Uniquely generated identifier key by LoginRadius that is activated after successful authentication.
            next_cursor: Cursor value if not all contacts can be retrieved once.
		
        Returns:
            Response Model containing Checkins with next cursor
        25.2.2
        """

        if(self._lr_object.is_null_or_whitespace(access_token)):
            raise Exception(self._lr_object.get_validation_message("access_token"))

        if(self._lr_object.is_null_or_whitespace(next_cursor)):
            raise Exception(self._lr_object.get_validation_message("next_cursor"))

        query_parameters = {}
        query_parameters["access_token"] = access_token
        query_parameters["nextCursor"] = next_cursor

        resource_path = "api/v2/checkin"
        return self._lr_object.execute("GET", resource_path, query_parameters, None)

    def get_contacts(self, access_token, next_cursor=''):
        """The Contact API is used to get contacts/friends/connections data from the user's social account.This is one of the APIs that makes up the LoginRadius Friend Invite System. The data will normalized into LoginRadius' standard data format. This API requires setting permissions in your LoginRadius Dashboard. <br><br><b>Note:</b> Facebook restricts access to the list of friends that is returned. When using the Contacts API with Facebook you will only receive friends that have accepted some permissions with your app. <br><br><b>Supported Providers:</b> Facebook, Foursquare, Google, LinkedIn, Live, Twitter, Vkontakte, Yahoo
        
        Args:
            access_token: Uniquely generated identifier key by LoginRadius that is activated after successful authentication.
            next_cursor: Cursor value if not all contacts can be retrieved once.
		
        Returns:
            Response containing Definition of Contact Data with Cursor
        27.1
        """

        if(self._lr_object.is_null_or_whitespace(access_token)):
            raise Exception(self._lr_object.get_validation_message("access_token"))

        query_parameters = {}
        query_parameters["access_token"] = access_token
        if(not self._lr_object.is_null_or_whitespace(next_cursor)):
            query_parameters["nextCursor"] = next_cursor

        resource_path = "api/v2/contact"
        return self._lr_object.execute("GET", resource_path, query_parameters, None)

    def get_events(self, access_token):
        """The Event API is used to get the event data from the user's social account.<br><br><b>Supported Providers:</b> Facebook, Live
        
        Args:
            access_token: Uniquely generated identifier key by LoginRadius that is activated after successful authentication.
		
        Returns:
            Response Containing List of Events Data
        28.2.1
        """

        if(self._lr_object.is_null_or_whitespace(access_token)):
            raise Exception(self._lr_object.get_validation_message("access_token"))

        query_parameters = {}
        query_parameters["access_token"] = access_token

        resource_path = "api/v2/event"
        return self._lr_object.execute("GET", resource_path, query_parameters, None)

    def get_events_with_cursor(self, access_token, next_cursor):
        """The Event API is used to get the event data from the user's social account.<br><br><b>Supported Providers:</b> Facebook, Live
        
        Args:
            access_token: Uniquely generated identifier key by LoginRadius that is activated after successful authentication.
            next_cursor: Cursor value if not all contacts can be retrieved once.
		
        Returns:
            Response Model containing Events with next cursor
        28.2.2
        """

        if(self._lr_object.is_null_or_whitespace(access_token)):
            raise Exception(self._lr_object.get_validation_message("access_token"))

        if(self._lr_object.is_null_or_whitespace(next_cursor)):
            raise Exception(self._lr_object.get_validation_message("next_cursor"))

        query_parameters = {}
        query_parameters["access_token"] = access_token
        query_parameters["nextCursor"] = next_cursor

        resource_path = "api/v2/event"
        return self._lr_object.execute("GET", resource_path, query_parameters, None)

    def get_followings(self, access_token):
        """Get the following user list from the user's social account.<br><br><b>Supported Providers:</b> Twitter
        
        Args:
            access_token: Uniquely generated identifier key by LoginRadius that is activated after successful authentication.
		
        Returns:
            Response Containing List of Contacts Data
        29.2.1
        """

        if(self._lr_object.is_null_or_whitespace(access_token)):
            raise Exception(self._lr_object.get_validation_message("access_token"))

        query_parameters = {}
        query_parameters["access_token"] = access_token

        resource_path = "api/v2/following"
        return self._lr_object.execute("GET", resource_path, query_parameters, None)

    def get_followings_with_cursor(self, access_token, next_cursor):
        """Get the following user list from the user's social account.<br><br><b>Supported Providers:</b> Twitter
        
        Args:
            access_token: Uniquely generated identifier key by LoginRadius that is activated after successful authentication.
            next_cursor: Cursor value if not all contacts can be retrieved once.
		
        Returns:
            Response containing Definition of Contact Data with Cursor
        29.2.2
        """

        if(self._lr_object.is_null_or_whitespace(access_token)):
            raise Exception(self._lr_object.get_validation_message("access_token"))

        if(self._lr_object.is_null_or_whitespace(next_cursor)):
            raise Exception(self._lr_object.get_validation_message("next_cursor"))

        query_parameters = {}
        query_parameters["access_token"] = access_token
        query_parameters["nextCursor"] = next_cursor

        resource_path = "api/v2/following"
        return self._lr_object.execute("GET", resource_path, query_parameters, None)

    def get_groups(self, access_token):
        """The Group API is used to get group data from the user's social account.<br><br><b>Supported Providers:</b> Facebook, Vkontakte
        
        Args:
            access_token: Uniquely generated identifier key by LoginRadius that is activated after successful authentication.
		
        Returns:
            Response Containing List of Groups Data
        30.2.1
        """

        if(self._lr_object.is_null_or_whitespace(access_token)):
            raise Exception(self._lr_object.get_validation_message("access_token"))

        query_parameters = {}
        query_parameters["access_token"] = access_token

        resource_path = "api/v2/group"
        return self._lr_object.execute("GET", resource_path, query_parameters, None)

    def get_groups_with_cursor(self, access_token, next_cursor):
        """The Group API is used to get group data from the user's social account.<br><br><b>Supported Providers:</b> Facebook, Vkontakte
        
        Args:
            access_token: Uniquely generated identifier key by LoginRadius that is activated after successful authentication.
            next_cursor: Cursor value if not all contacts can be retrieved once.
		
        Returns:
            Response Model containing Groups with next cursor
        30.2.2
        """

        if(self._lr_object.is_null_or_whitespace(access_token)):
            raise Exception(self._lr_object.get_validation_message("access_token"))

        if(self._lr_object.is_null_or_whitespace(next_cursor)):
            raise Exception(self._lr_object.get_validation_message("next_cursor"))

        query_parameters = {}
        query_parameters["access_token"] = access_token
        query_parameters["nextCursor"] = next_cursor

        resource_path = "api/v2/group"
        return self._lr_object.execute("GET", resource_path, query_parameters, None)

    def get_likes(self, access_token):
        """The Like API is used to get likes data from the user's social account.<br><br><b>Supported Providers:</b> Facebook
        
        Args:
            access_token: Uniquely generated identifier key by LoginRadius that is activated after successful authentication.
		
        Returns:
            Response Containing List of Likes Data
        31.2.1
        """

        if(self._lr_object.is_null_or_whitespace(access_token)):
            raise Exception(self._lr_object.get_validation_message("access_token"))

        query_parameters = {}
        query_parameters["access_token"] = access_token

        resource_path = "api/v2/like"
        return self._lr_object.execute("GET", resource_path, query_parameters, None)

    def get_likes_with_cursor(self, access_token, next_cursor):
        """The Like API is used to get likes data from the user's social account.<br><br><b>Supported Providers:</b> Facebook
        
        Args:
            access_token: Uniquely generated identifier key by LoginRadius that is activated after successful authentication.
            next_cursor: Cursor value if not all contacts can be retrieved once.
		
        Returns:
            Response Model containing Likes with next cursor
        31.2.2
        """

        if(self._lr_object.is_null_or_whitespace(access_token)):
            raise Exception(self._lr_object.get_validation_message("access_token"))

        if(self._lr_object.is_null_or_whitespace(next_cursor)):
            raise Exception(self._lr_object.get_validation_message("next_cursor"))

        query_parameters = {}
        query_parameters["access_token"] = access_token
        query_parameters["nextCursor"] = next_cursor

        resource_path = "api/v2/like"
        return self._lr_object.execute("GET", resource_path, query_parameters, None)

    def get_mentions(self, access_token):
        """The Mention API is used to get mentions data from the user's social account.<br><br><b>Supported Providers:</b> Twitter
        
        Args:
            access_token: Uniquely generated identifier key by LoginRadius that is activated after successful authentication.
		
        Returns:
            Response Containing List of Status Data
        32.1
        """

        if(self._lr_object.is_null_or_whitespace(access_token)):
            raise Exception(self._lr_object.get_validation_message("access_token"))

        query_parameters = {}
        query_parameters["access_token"] = access_token

        resource_path = "api/v2/mention"
        return self._lr_object.execute("GET", resource_path, query_parameters, None)

    def post_message(self, access_token, message, subject,
        to):
        """Post Message API is used to post messages to the user's contacts.<br><br><b>Supported Providers:</b> Twitter, LinkedIn <br><br>The Message API is used to post messages to the user?s contacts. This is one of the APIs that makes up the LoginRadius Friend Invite System. After using the Contact API, you can send messages to the retrieved contacts. This API requires setting permissions in your LoginRadius Dashboard.<br><br>GET & POST Message API work the same way except the API method is different
        
        Args:
            access_token: Uniquely generated identifier key by LoginRadius that is activated after successful authentication.
            message: Body of your message
            subject: Subject of your message
            to: Recipient's social provider's id
		
        Returns:
            Response containing Definition for Complete Validation data
        33.1
        """

        if(self._lr_object.is_null_or_whitespace(access_token)):
            raise Exception(self._lr_object.get_validation_message("access_token"))

        if(self._lr_object.is_null_or_whitespace(message)):
            raise Exception(self._lr_object.get_validation_message("message"))

        if(self._lr_object.is_null_or_whitespace(subject)):
            raise Exception(self._lr_object.get_validation_message("subject"))

        if(self._lr_object.is_null_or_whitespace(to)):
            raise Exception(self._lr_object.get_validation_message("to"))

        query_parameters = {}
        query_parameters["access_token"] = access_token
        query_parameters["message"] = message
        query_parameters["subject"] = subject
        query_parameters["to"] = to

        resource_path = "api/v2/message"
        return self._lr_object.execute("POST", resource_path, query_parameters, None)

    def get_page(self, access_token, page_name):
        """The Page API is used to get the page data from the user's social account.<br><br><b>Supported Providers:</b>  Facebook, LinkedIn
        
        Args:
            access_token: Uniquely generated identifier key by LoginRadius that is activated after successful authentication.
            page_name: Name of the page you want to retrieve info from
		
        Returns:
            Response containing Definition of Complete page data
        34.1
        """

        if(self._lr_object.is_null_or_whitespace(access_token)):
            raise Exception(self._lr_object.get_validation_message("access_token"))

        if(self._lr_object.is_null_or_whitespace(page_name)):
            raise Exception(self._lr_object.get_validation_message("page_name"))

        query_parameters = {}
        query_parameters["access_token"] = access_token
        query_parameters["pageName"] = page_name

        resource_path = "api/v2/page"
        return self._lr_object.execute("GET", resource_path, query_parameters, None)

    def get_photos(self, access_token, album_id):
        """The Photo API is used to get photo data from the user's social account.<br><br><b>Supported Providers:</b>  Facebook, Foursquare, Google, Live, Vkontakte
        
        Args:
            access_token: Uniquely generated identifier key by LoginRadius that is activated after successful authentication.
            album_id: The id of the album you want to retrieve info from
		
        Returns:
            Response Containing List of Photos Data
        35.1
        """

        if(self._lr_object.is_null_or_whitespace(access_token)):
            raise Exception(self._lr_object.get_validation_message("access_token"))

        if(self._lr_object.is_null_or_whitespace(album_id)):
            raise Exception(self._lr_object.get_validation_message("album_id"))

        query_parameters = {}
        query_parameters["access_token"] = access_token
        query_parameters["albumId"] = album_id

        resource_path = "api/v2/photo"
        return self._lr_object.execute("GET", resource_path, query_parameters, None)

    def get_posts(self, access_token):
        """The Post API is used to get post message data from the user's social account.<br><br><b>Supported Providers:</b>  Facebook
        
        Args:
            access_token: Uniquely generated identifier key by LoginRadius that is activated after successful authentication.
		
        Returns:
            Response Containing List of Posts Data
        36.1
        """

        if(self._lr_object.is_null_or_whitespace(access_token)):
            raise Exception(self._lr_object.get_validation_message("access_token"))

        query_parameters = {}
        query_parameters["access_token"] = access_token

        resource_path = "api/v2/post"
        return self._lr_object.execute("GET", resource_path, query_parameters, None)

    def status_posting(self, access_token, caption, description,
        imageurl, status, title, url,
        shorturl='0'):
        """The Status API is used to update the status on the user's wall.<br><br><b>Supported Providers:</b>  Facebook, Twitter, LinkedIn
        
        Args:
            access_token: Uniquely generated identifier key by LoginRadius that is activated after successful authentication.
            caption: Message displayed below the description(Requires URL, Under 70 Characters).
            description: Description of the displayed URL and Image(Requires URL)
            imageurl: Image to be displayed in the share(Requires URL).
            status: Main body of the Status update.
            title: Title of Linked URL
            url: URL to be included when clicking on the share.
            shorturl: short url
		
        Returns:
            Response conatining Definition of Validation and Short URL data
        37.2
        """

        if(self._lr_object.is_null_or_whitespace(access_token)):
            raise Exception(self._lr_object.get_validation_message("access_token"))

        if(self._lr_object.is_null_or_whitespace(caption)):
            raise Exception(self._lr_object.get_validation_message("caption"))

        if(self._lr_object.is_null_or_whitespace(description)):
            raise Exception(self._lr_object.get_validation_message("description"))

        if(self._lr_object.is_null_or_whitespace(imageurl)):
            raise Exception(self._lr_object.get_validation_message("imageurl"))

        if(self._lr_object.is_null_or_whitespace(status)):
            raise Exception(self._lr_object.get_validation_message("status"))

        if(self._lr_object.is_null_or_whitespace(title)):
            raise Exception(self._lr_object.get_validation_message("title"))

        if(self._lr_object.is_null_or_whitespace(url)):
            raise Exception(self._lr_object.get_validation_message("url"))

        query_parameters = {}
        query_parameters["access_token"] = access_token
        query_parameters["caption"] = caption
        query_parameters["description"] = description
        query_parameters["imageurl"] = imageurl
        query_parameters["status"] = status
        query_parameters["title"] = title
        query_parameters["url"] = url
        if(not self._lr_object.is_null_or_whitespace(shorturl)):
            query_parameters["shorturl"] = shorturl

        resource_path = "api/v2/status"
        return self._lr_object.execute("POST", resource_path, query_parameters, None)

    def trackable_status_posting(self, access_token, status_model):
        """The Trackable status API works very similar to the Status API but it returns a Post id that you can use to track the stats(shares, likes, comments) for a specific share/post/status update. This API requires setting permissions in your LoginRadius Dashboard.<br><br> The Trackable Status API is used to update the status on the user's wall and return an Post ID value. It is commonly referred to as Permission based sharing or Push notifications.<br><br> POST Input Parameter Format: application/x-www-form-urlencoded
        
        Args:
            access_token: Uniquely generated identifier key by LoginRadius that is activated after successful authentication.
            status_model: Model Class containing Definition of payload for Status API
		
        Returns:
            Response containing Definition for Complete status data
        37.6
        """

        if(self._lr_object.is_null_or_whitespace(access_token)):
            raise Exception(self._lr_object.get_validation_message("access_token"))
        if(status_model is None):
            raise Exception(self._lr_object.get_validation_message("status_model"))

        query_parameters = {}
        query_parameters["access_token"] = access_token

        resource_path = "api/v2/status/trackable"
        return self._lr_object.execute("POST", resource_path, query_parameters, status_model)

    def get_trackable_status_stats(self, access_token, caption, description,
        imageurl, status, title, url):
        """The Trackable status API works very similar to the Status API but it returns a Post id that you can use to track the stats(shares, likes, comments) for a specific share/post/status update. This API requires setting permissions in your LoginRadius Dashboard.<br><br> The Trackable Status API is used to update the status on the user's wall and return an Post ID value. It is commonly referred to as Permission based sharing or Push notifications.
        
        Args:
            access_token: Uniquely generated identifier key by LoginRadius that is activated after successful authentication.
            caption: Message displayed below the description(Requires URL, Under 70 Characters).
            description: Description of the displayed URL and Image(Requires URL)
            imageurl: Image to be displayed in the share(Requires URL).
            status: Main body of the Status update.
            title: Title of Linked URL
            url: URL to be included when clicking on the share.
		
        Returns:
            Response containing Definition for Complete status data
        37.7
        """

        if(self._lr_object.is_null_or_whitespace(access_token)):
            raise Exception(self._lr_object.get_validation_message("access_token"))

        if(self._lr_object.is_null_or_whitespace(caption)):
            raise Exception(self._lr_object.get_validation_message("caption"))

        if(self._lr_object.is_null_or_whitespace(description)):
            raise Exception(self._lr_object.get_validation_message("description"))

        if(self._lr_object.is_null_or_whitespace(imageurl)):
            raise Exception(self._lr_object.get_validation_message("imageurl"))

        if(self._lr_object.is_null_or_whitespace(status)):
            raise Exception(self._lr_object.get_validation_message("status"))

        if(self._lr_object.is_null_or_whitespace(title)):
            raise Exception(self._lr_object.get_validation_message("title"))

        if(self._lr_object.is_null_or_whitespace(url)):
            raise Exception(self._lr_object.get_validation_message("url"))

        query_parameters = {}
        query_parameters["access_token"] = access_token
        query_parameters["caption"] = caption
        query_parameters["description"] = description
        query_parameters["imageurl"] = imageurl
        query_parameters["status"] = status
        query_parameters["title"] = title
        query_parameters["url"] = url

        resource_path = "api/v2/status/trackable/js"
        return self._lr_object.execute("GET", resource_path, query_parameters, None)

    def trackable_status_fetching(self, post_id):
        """The Trackable status API works very similar to the Status API but it returns a Post id that you can use to track the stats(shares, likes, comments) for a specific share/post/status update. This API requires setting permissions in your LoginRadius Dashboard.<br><br> This API is used to retrieve a tracked post based on the passed in post ID value. This API requires setting permissions in your LoginRadius Dashboard.<br><br> <b>Note:</b> To utilize this API you need to find the ID for the post you want to track, which might require using Trackable Status Posting API first.
        
        Args:
            post_id: Post ID value
		
        Returns:
            Response containing Definition of Complete Status Update data
        37.8
        """

        if(self._lr_object.is_null_or_whitespace(post_id)):
            raise Exception(self._lr_object.get_validation_message("post_id"))

        query_parameters = {}
        query_parameters["postId"] = post_id
        query_parameters["secret"] = self._lr_object.get_api_secret()

        resource_path = "api/v2/status/trackable"
        return self._lr_object.execute("GET", resource_path, query_parameters, None)

    def get_social_user_profile(self, access_token, fields=''):
        """The User Profile API is used to get social profile data from the user's social account after authentication.<br><br><b>Supported Providers:</b>  All
        
        Args:
            access_token: Uniquely generated identifier key by LoginRadius that is activated after successful authentication.
            fields: The fields parameter filters the API response so that the response only includes a specific set of fields
		
        Returns:
            Response containing Definition for Complete UserProfile data
        38.1
        """

        if(self._lr_object.is_null_or_whitespace(access_token)):
            raise Exception(self._lr_object.get_validation_message("access_token"))

        query_parameters = {}
        query_parameters["access_token"] = access_token
        if(not self._lr_object.is_null_or_whitespace(fields)):
            query_parameters["fields"] = fields

        resource_path = "api/v2/userprofile"
        return self._lr_object.execute("GET", resource_path, query_parameters, None)

    def get_refreshed_social_user_profile(self, access_token, fields=''):
        """The User Profile API is used to get the latest updated social profile data from the user's social account after authentication. The social profile will be retrieved via oAuth and OpenID protocols. The data is normalized into LoginRadius' standard data format. This API should be called using the access token retrieved from the refresh access token API.
        
        Args:
            access_token: Uniquely generated identifier key by LoginRadius that is activated after successful authentication.
            fields: The fields parameter filters the API response so that the response only includes a specific set of fields
		
        Returns:
            Response containing Definition for Complete UserProfile data
        38.2
        """

        if(self._lr_object.is_null_or_whitespace(access_token)):
            raise Exception(self._lr_object.get_validation_message("access_token"))

        query_parameters = {}
        query_parameters["access_token"] = access_token
        if(not self._lr_object.is_null_or_whitespace(fields)):
            query_parameters["fields"] = fields

        resource_path = "api/v2/userprofile/refresh"
        return self._lr_object.execute("GET", resource_path, query_parameters, None)

    def get_videos(self, access_token, next_cursor):
        """The Video API is used to get video files data from the user's social account.<br><br><b>Supported Providers:</b>   Facebook, Google, Live, Vkontakte
        
        Args:
            access_token: Uniquely generated identifier key by LoginRadius that is activated after successful authentication.
            next_cursor: Cursor value if not all contacts can be retrieved once.
		
        Returns:
            Response containing Definition of Video Data with Cursor
        39.2
        """

        if(self._lr_object.is_null_or_whitespace(access_token)):
            raise Exception(self._lr_object.get_validation_message("access_token"))

        if(self._lr_object.is_null_or_whitespace(next_cursor)):
            raise Exception(self._lr_object.get_validation_message("next_cursor"))

        query_parameters = {}
        query_parameters["access_token"] = access_token
        query_parameters["nextCursor"] = next_cursor

        resource_path = "api/v2/video"
        return self._lr_object.execute("GET", resource_path, query_parameters, None)



import setuptools

# read the contents of your README file
from os import path
this_directory = path.abspath(path.dirname(__file__))
with open(path.join(this_directory, 'README.md')) as f:
    long_description = f.read()

setuptools.setup(
    name = 'LoginRadius-v2',
    version='10.0.0.post1',
    long_description=long_description,
    long_description_content_type='text/markdown',
	packages=setuptools.find_packages(),
    description = 'Customer identity and access management for Python.',
    author='LoginRadius',
    author_email='developers@loginradius.com',
    url='https://loginradius.com/',
    classifiers=['Programming Language :: Python', 'Programming Language :: Python :: 2.7',
                 'Operating System :: OS Independent', 'License :: OSI Approved :: MIT License',
                 'Development Status :: 5 - Production/Stable', 'Intended Audience :: Developers',
                 'Topic :: Internet', 'Topic :: Internet :: WWW/HTTP',
                 'Topic :: Software Development :: Libraries :: Python Modules']
)



# -- coding: utf-8 --
# Created by LoginRadius Development Team
# Copyright 2019 LoginRadius Inc. All rights reserved.
#


class OneTouchLoginApi:

    def __init__(self, lr_object):
        """
        :param lr_object: this is the reference to the parent LoginRadius object.
        """
        self._lr_object = lr_object

    def one_touch_login_by_email(self, one_touch_login_by_email_model, one_touch_login_email_template=None, redirecturl=None,
        welcomeemailtemplate=None):
        """This API is used to send a link to a specified email for a frictionless login/registration
        
        Args:
            one_touch_login_by_email_model: Model Class containing Definition of payload for OneTouchLogin By EmailModel API
            one_touch_login_email_template: Name of the One Touch Login Email Template
            redirecturl: Url where the user will redirect after success authentication
            welcomeemailtemplate: Name of the welcome email template
		
        Returns:
            Response containing Definition of Complete Validation data
        1.2
        """
        if(one_touch_login_by_email_model is None):
            raise Exception(self._lr_object.get_validation_message("one_touch_login_by_email_model"))

        query_parameters = {}
        query_parameters["apiKey"] = self._lr_object.get_api_key()
        if(not self._lr_object.is_null_or_whitespace(one_touch_login_email_template)):
            query_parameters["oneTouchLoginEmailTemplate"] = one_touch_login_email_template
        if(not self._lr_object.is_null_or_whitespace(redirecturl)):
            query_parameters["redirecturl"] = redirecturl
        if(not self._lr_object.is_null_or_whitespace(welcomeemailtemplate)):
            query_parameters["welcomeemailtemplate"] = welcomeemailtemplate

        resource_path = "identity/v2/auth/onetouchlogin/email"
        return self._lr_object.execute("POST", resource_path, query_parameters, one_touch_login_by_email_model)

    def one_touch_login_by_phone(self, one_touch_login_by_phone_model, sms_template=None):
        """This API is used to send one time password to a given phone number for a frictionless login/registration.
        
        Args:
            one_touch_login_by_phone_model: Model Class containing Definition of payload for OneTouchLogin By PhoneModel API
            sms_template: SMS Template name
		
        Returns:
            Response containing Definition of Complete Validation data
        1.4
        """
        if(one_touch_login_by_phone_model is None):
            raise Exception(self._lr_object.get_validation_message("one_touch_login_by_phone_model"))

        query_parameters = {}
        query_parameters["apiKey"] = self._lr_object.get_api_key()
        if(not self._lr_object.is_null_or_whitespace(sms_template)):
            query_parameters["smsTemplate"] = sms_template

        resource_path = "identity/v2/auth/onetouchlogin/phone"
        return self._lr_object.execute("POST", resource_path, query_parameters, one_touch_login_by_phone_model)

    def one_touch_login_otp_verification(self, otp, phone, fields='',
        sms_template=None):
        """This API is used to verify the otp for One Touch Login.
        
        Args:
            otp: The Verification Code
            phone: New Phone Number
            fields: The fields parameter filters the API response so that the response only includes a specific set of fields
            sms_template: SMS Template name
		
        Returns:
            Response Containing Access Token and Complete Profile Data
        1.5
        """

        if(self._lr_object.is_null_or_whitespace(otp)):
            raise Exception(self._lr_object.get_validation_message("otp"))

        if(self._lr_object.is_null_or_whitespace(phone)):
            raise Exception(self._lr_object.get_validation_message("phone"))

        query_parameters = {}
        query_parameters["apiKey"] = self._lr_object.get_api_key()
        query_parameters["otp"] = otp
        if(not self._lr_object.is_null_or_whitespace(fields)):
            query_parameters["fields"] = fields
        if(not self._lr_object.is_null_or_whitespace(sms_template)):
            query_parameters["smsTemplate"] = sms_template

        body_parameters = {}
        body_parameters["phone"] = phone

        resource_path = "identity/v2/auth/onetouchlogin/phone/verify"
        return self._lr_object.execute("PUT", resource_path, query_parameters, body_parameters)

    def one_touch_email_verification(self, verification_token, welcome_email_template=None):
        """This API verifies the provided token for One Touch Login
        
        Args:
            verification_token: Verification token received in the email
            welcome_email_template: Name of the welcome email template
		
        Returns:
            Complete verified response data
        8.4.2
        """

        if(self._lr_object.is_null_or_whitespace(verification_token)):
            raise Exception(self._lr_object.get_validation_message("verification_token"))

        query_parameters = {}
        query_parameters["apiKey"] = self._lr_object.get_api_key()
        query_parameters["verificationToken"] = verification_token
        if(not self._lr_object.is_null_or_whitespace(welcome_email_template)):
            query_parameters["welcomeEmailTemplate"] = welcome_email_template

        resource_path = "identity/v2/auth/email/onetouchlogin"
        return self._lr_object.execute("GET", resource_path, query_parameters, None)

    def one_touch_login_ping(self, client_guid, fields=''):
        """This API is used to check if the One Touch Login link has been clicked or not.
        
        Args:
            client_guid: Unique string used in the Smart Login request
            fields: The fields parameter filters the API response so that the response only includes a specific set of fields
		
        Returns:
            Response containing User Profile Data and access token
        9.21.2
        """

        if(self._lr_object.is_null_or_whitespace(client_guid)):
            raise Exception(self._lr_object.get_validation_message("client_guid"))

        query_parameters = {}
        query_parameters["apiKey"] = self._lr_object.get_api_key()
        query_parameters["clientGuid"] = client_guid
        if(not self._lr_object.is_null_or_whitespace(fields)):
            query_parameters["fields"] = fields

        resource_path = "identity/v2/auth/login/smartlogin/ping"
        return self._lr_object.execute("GET", resource_path, query_parameters, None)
